/* This file is generated by glib-genmarshal, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */
#ifndef ___IBUS_MARSHAL_MARSHAL_H__
#define ___IBUS_MARSHAL_MARSHAL_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* VOID:VOID (./ibusmarshalers.list:1) */
#define _ibus_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:OBJECT (./ibusmarshalers.list:2) */
#define _ibus_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT

/* VOID:POINTER (./ibusmarshalers.list:3) */
#define _ibus_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER

/* VOID:STRING (./ibusmarshalers.list:4) */
#define _ibus_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING

/* VOID:STRING,INT (./ibusmarshalers.list:5) */
G_GNUC_INTERNAL
void _ibus_marshal_VOID__STRING_INT (GClosure     *closure,
                                     GValue       *return_value,
                                     guint         n_param_values,
                                     const GValue *param_values,
                                     gpointer      invocation_hint,
                                     gpointer      marshal_data);

/* VOID:STRING,UINT (./ibusmarshalers.list:6) */
G_GNUC_INTERNAL
void _ibus_marshal_VOID__STRING_UINT (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
                                      const GValue *param_values,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);

/* BOOLEAN:POINTER (./ibusmarshalers.list:7) */
G_GNUC_INTERNAL
void _ibus_marshal_BOOLEAN__POINTER (GClosure     *closure,
                                     GValue       *return_value,
                                     guint         n_param_values,
                                     const GValue *param_values,
                                     gpointer      invocation_hint,
                                     gpointer      marshal_data);

/* BOOLEAN:POINTER,POINTER (./ibusmarshalers.list:8) */
G_GNUC_INTERNAL
void _ibus_marshal_BOOLEAN__POINTER_POINTER (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

/* BOOLEAN:UINT,UINT (./ibusmarshalers.list:9) */
G_GNUC_INTERNAL
void _ibus_marshal_BOOLEAN__UINT_UINT (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);

/* BOOLEAN:UINT,UINT,UINT (./ibusmarshalers.list:10) */
G_GNUC_INTERNAL
void _ibus_marshal_BOOLEAN__UINT_UINT_UINT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* BOOLEAN:ULONG (./ibusmarshalers.list:11) */
G_GNUC_INTERNAL
void _ibus_marshal_BOOLEAN__ULONG (GClosure     *closure,
                                   GValue       *return_value,
                                   guint         n_param_values,
                                   const GValue *param_values,
                                   gpointer      invocation_hint,
                                   gpointer      marshal_data);

/* VOID:INT,INT,INT,INT (./ibusmarshalers.list:12) */
G_GNUC_INTERNAL
void _ibus_marshal_VOID__INT_INT_INT_INT (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);

/* VOID:INT,UINT (./ibusmarshalers.list:13) */
G_GNUC_INTERNAL
void _ibus_marshal_VOID__INT_UINT (GClosure     *closure,
                                   GValue       *return_value,
                                   guint         n_param_values,
                                   const GValue *param_values,
                                   gpointer      invocation_hint,
                                   gpointer      marshal_data);

/* VOID:OBJECT,UINT,BOOLEAN (./ibusmarshalers.list:14) */
G_GNUC_INTERNAL
void _ibus_marshal_VOID__OBJECT_UINT_BOOLEAN (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:OBJECT,UINT,BOOLEAN,UINT (./ibusmarshalers.list:15) */
G_GNUC_INTERNAL
void _ibus_marshal_VOID__OBJECT_UINT_BOOLEAN_UINT (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

/* VOID:OBJECT,UINT,UINT (./ibusmarshalers.list:16) */
G_GNUC_INTERNAL
void _ibus_marshal_VOID__OBJECT_UINT_UINT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);

/* VOID:OBJECT,BOOLEAN (./ibusmarshalers.list:17) */
G_GNUC_INTERNAL
void _ibus_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
                                         const GValue *param_values,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);

/* VOID:BOXED,BOOLEAN (./ibusmarshalers.list:18) */
G_GNUC_INTERNAL
void _ibus_marshal_VOID__BOXED_BOOLEAN (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);

/* VOID:BOXED (./ibusmarshalers.list:19) */
#define _ibus_marshal_VOID__BOXED	g_cclosure_marshal_VOID__BOXED

/* VOID:STRING,STRING (./ibusmarshalers.list:20) */
G_GNUC_INTERNAL
void _ibus_marshal_VOID__STRING_STRING (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);

/* VOID:STRING,STRING,VARIANT (./ibusmarshalers.list:21) */
G_GNUC_INTERNAL
void _ibus_marshal_VOID__STRING_STRING_VARIANT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);

/* VOID:STRING,STRING,STRING (./ibusmarshalers.list:22) */
G_GNUC_INTERNAL
void _ibus_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);

/* VOID:UCHAR,UINT,UINT,UINT,BOOLEAN (./ibusmarshalers.list:23) */
G_GNUC_INTERNAL
void _ibus_marshal_VOID__UCHAR_UINT_UINT_UINT_BOOLEAN (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
                                                       const GValue *param_values,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);

/* VOID:UINT (./ibusmarshalers.list:24) */
#define _ibus_marshal_VOID__UINT	g_cclosure_marshal_VOID__UINT

/* VOID:UINT,POINTER (./ibusmarshalers.list:25) */
#define _ibus_marshal_VOID__UINT_POINTER	g_cclosure_marshal_VOID__UINT_POINTER

/* VOID:UINT,UINT (./ibusmarshalers.list:26) */
G_GNUC_INTERNAL
void _ibus_marshal_VOID__UINT_UINT (GClosure     *closure,
                                    GValue       *return_value,
                                    guint         n_param_values,
                                    const GValue *param_values,
                                    gpointer      invocation_hint,
                                    gpointer      marshal_data);

/* VOID:UINT,UINT,UINT (./ibusmarshalers.list:27) */
G_GNUC_INTERNAL
void _ibus_marshal_VOID__UINT_UINT_UINT (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
                                         const GValue *param_values,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);

/* VOID:POINTER,UINT (./ibusmarshalers.list:28) */
G_GNUC_INTERNAL
void _ibus_marshal_VOID__POINTER_UINT (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);

/* VOID:VARIANT (./ibusmarshalers.list:29) */
#define _ibus_marshal_VOID__VARIANT	g_cclosure_marshal_VOID__VARIANT

/* OBJECT:STRING (./ibusmarshalers.list:30) */
G_GNUC_INTERNAL
void _ibus_marshal_OBJECT__STRING (GClosure     *closure,
                                   GValue       *return_value,
                                   guint         n_param_values,
                                   const GValue *param_values,
                                   gpointer      invocation_hint,
                                   gpointer      marshal_data);


G_END_DECLS

#endif /* ___IBUS_MARSHAL_MARSHAL_H__ */
